package com.ruoyi.order.service;

import java.util.List;
import com.ruoyi.order.domain.TbOrderDetail;

/**
 * 单据明细Service接口
 * 
 * @author 原动力
 * @date 2023-05-24
 */
public interface ITbOrderDetailService 
{
    /**
     * 查询单据明细
     * 
     * @param id 单据明细主键
     * @return 单据明细
     */
    public TbOrderDetail selectTbOrderDetailById(Long id);

    /**
     * 查询单据明细列表
     * 
     * @param tbOrderDetail 单据明细
     * @return 单据明细集合
     */
    public List<TbOrderDetail> selectTbOrderDetailList(TbOrderDetail tbOrderDetail);

    /**
     * 新增单据明细
     * 
     * @param tbOrderDetail 单据明细
     * @return 结果
     */
    public int insertTbOrderDetail(TbOrderDetail tbOrderDetail);

    /**
     * 修改单据明细
     * 
     * @param tbOrderDetail 单据明细
     * @return 结果
     */
    public int updateTbOrderDetail(TbOrderDetail tbOrderDetail);

    /**
     * 批量删除单据明细
     * 
     * @param ids 需要删除的单据明细主键集合
     * @return 结果
     */
    public int deleteTbOrderDetailByIds(Long[] ids);

    /**
     * 删除单据明细信息
     * 
     * @param id 单据明细主键
     * @return 结果
     */
    public int deleteTbOrderDetailById(Long id);
}
